@@ -20,6 +20,7 @@
 
 #include "kateprojectcodeanalysistoolcppcheck.h"
 
+#include <QThread>
 #include <QRegularExpression>
 #include <klocalizedstring.h>
 
@@ -55,6 +56,8 @@ QStringList KateProjectCodeAnalysisToolCppcheck::arguments()
     QStringList _args;
 
     _args << QStringLiteral("-q")
+          << QStringLiteral("-f")
+          << QStringLiteral("-j") + QString::number(QThread::idealThreadCount())
           << QStringLiteral("--inline-suppr")
           << QStringLiteral("--enable=all")
           << QStringLiteral("--template={file}////{line}////{severity}////{message}")
