@@ -535,7 +535,7 @@ void KateMainWindow::slotNewToolbarConfig()
 {
     applyMainWindowSettings(KConfigGroup(KSharedConfig::openConfig(), "MainWindow"));
 
-    // we neeed to relod all View's XML Gui from disk to ensure toolbar
+    // we need to reload all View's XML Gui from disk to ensure toolbar
     // changes are applied to all views.
     reloadXmlGui();
 }
@@ -564,6 +564,7 @@ void KateMainWindow::readOptions()
 
     const KConfigGroup generalGroup(config, "General");
     m_modNotification = generalGroup.readEntry("Modified Notification", false);
+    m_modCloseAfterLast = generalGroup.readEntry("Close After Last", false);
     KateApp::self()->documentManager()->setSaveMetaInfos(generalGroup.readEntry("Save Meta Infos", true));
     KateApp::self()->documentManager()->setDaysMetaInfos(generalGroup.readEntry("Days Meta Infos", 30));
 
@@ -1106,7 +1107,7 @@ QObject *KateMainWindow::pluginView(const QString &name)
         return nullptr;
     }
 
-    return m_pluginViews.contains(plugin) ? m_pluginViews.value(plugin) : 0;
+    return m_pluginViews.contains(plugin) ? m_pluginViews.value(plugin) : nullptr;
 }
 
 void KateMainWindow::mousePressEvent(QMouseEvent *e)
